#

##

##

###

###

###

###

###

    	squishy
    		https://en.wikipedia.org/wiki/Netfilter#

    	objectives

    		[ ] block all ports except

    		[ ] Burp Suite
    			[ ] https://portswigger.net/burp

    		[ ] Snyk
    			[ ] https://snyk.io/

    		[ ] Checkmarx
    			[ ] https://checkmarx.com/

    		[ ] Invicti
    			[ ] https://www.invicti.com/

    		[ ] Kali Linux

    		[ ] https://sentry.io/welcome/

    	important

    		docker
    			modprode:

    				apt-get update
    				apt-get install linux-headers-$(uname -r) linux-modules-extra-$(uname -r)

    				apt-get install kmod -y

    				--cap-add=NET_ADMIN --cap-add=NET_RAW --cap-add=NET_BIND_SERVICE --cap-add=SYS_MODULE

    		current
    			nft list ruleset

    		tcpdump
    			apt install tcpdump -y

    			tcpdump -i tcp

    				tcpdump -i eth0

    		show the network interfaces
    			[prompt] ip link show

    				lo
    				enp0s31f6
    				br-3c9d77222953
    				docker0
    				hss0
    				veth7075590@if12

    		wireshark